@@ -4,11 +4,11 @@
 # related or neighboring rights to this document.  Attribution is requested
 # but not required.
 
-use strict; use warnings FATAL => 'all'; use v5.20;
+use strict; use warnings FATAL => 'all'; use feature qw/say state/;
 use utf8;
 
 package Spreadsheet::Edit::Preload;
-$Spreadsheet::Edit::Preload::VERSION = '3.000';
+$Spreadsheet::Edit::Preload::VERSION = '3.001';
 use Carp;
 use Import::Into;
 require Spreadsheet::Edit;
